@@ -1,5 +1,8 @@
-#!/bin/bash
+#!/bin/sh
 
+echo "Is not implemented, yet!" >&2
+
+exit 1
 IFACE="$1"
 
 if [ "$IFACE" = "" ]; then
@@ -15,12 +18,12 @@ if [ "$IPADDR" = "" ]; then
 	exit 2
 fi
 
-mkdir -m 700 -p testdir/{from,to,listdir}
+mkdir -m 700 -p testdir/from testdir/to testdir/listdir
 
 cat > rules <<EOF
 -d^[Dd]ont[Ss]ync\$
 +*.*
 EOF
 
-clsync -K example-cluster -c "$IPADDR" -M rsyncshell -L ./testdir/listdir -w 2 -p safe -t 5 -W ./testdir/from -S ./clsync-synchandler-rsync.sh -R rules $@
+clsync -K example-cluster -c "$IPADDR" -M rsyncshell -w 2 -p safe -t 5 -W ./testdir/from -S ./clsync-synchandler-rsync.sh -R rules $@
 
